@@ -11,6 +11,13 @@ import sys
 import signal
 import warnings
 from io import BytesIO
+from typing import Optional
+
+if os.name == "nt" and sys.getwindowsversion().major >= 10:  # noqa
+    import ctypes
+
+    # using 2 (default in recent PySide?) does not work in higher-res non-boot laptop screen
+    ctypes.windll.shcore.SetProcessDpiAwareness(1)  # noqa
 
 try:
     from PySide2 import QtCore
@@ -23,14 +30,14 @@ except ImportError as _e:
     if not os.path.exists(os.path.join(sys.prefix, 'conda-meta')):
         print('Using Anaconda is probably the most reliable method')
     print("E.g. make and use a new environment using conda-forge")
-    print('conda create -n py37forge -c conda-forge python=3.7 scipy pandas matplotlib PySide2')
+    print('conda create -n py39forge -c conda-forge python=3.9 scipy pandas matplotlib PySide2')
 
     sys.exit(-1)
 
 matplotlib.use('Qt5Agg')
 
 import getdist
-from getdist import plots, IniFile
+from getdist import plots, IniFile, chains
 from getdist.chain_grid import ChainDirGrid, file_root_to_root, get_chain_root_files, load_supported_grid
 from getdist.mcsamples import SettingError, ParamError
 
@@ -41,16 +48,16 @@ from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT as QNavigati
 
 import PySide2
 from PySide2.QtGui import QIcon, QKeySequence, QFont, QTextOption, QPixmap, QImage
-from PySide2.QtCore import Qt, SIGNAL, QSize, QSettings, QCoreApplication
+from PySide2.QtCore import Qt, SIGNAL, QSize, QSettings, QCoreApplication, QPoint
 from PySide2.QtWidgets import QListWidget, QMainWindow, QDialog, QApplication, QAbstractItemView, QAction, \
     QTabWidget, QWidget, QComboBox, QPushButton, QShortcut, QCheckBox, QRadioButton, QGridLayout, QVBoxLayout, \
     QSplitter, QHBoxLayout, QToolBar, QPlainTextEdit, QScrollArea, QFileDialog, QMessageBox, QTableWidgetItem, \
-    QLabel, QTableWidget, QListWidgetItem, QTextEdit
+    QLabel, QTableWidget, QListWidgetItem, QTextEdit, QDialogButtonBox
 
 os.environ['QT_API'] = 'pyside2'
 
-QApplication.setAttribute(Qt.AA_EnableHighDpiScaling)  # DPI support
-QCoreApplication.setAttribute(Qt.AA_UseHighDpiPixmaps)
+# works with or without this:
+# QApplication.setAttribute(Qt.AA_EnableHighDpiScaling)
 
 try:
     # If cosmomc is configured
@@ -70,13 +77,13 @@ class GuiSelectionError(Exception):
 
 
 class QStatusLogger(logging.Handler):
-    def __init__(self, parent):
-        super().__init__(level=logging.WARNING)
-        self.widget = parent
+    def __init__(self, parent, level=logging.WARNING):
+        super().__init__(level=level)
+        self.widget: 'MainWindow' = parent
 
     def emit(self, record):
         msg = self.format(record)
-        self.widget.showMessage(msg, color='red')
+        self.widget.showMessage(msg, error=(self.level == logging.WARNING))
 
     def write(self, m):
         pass
@@ -87,7 +94,7 @@ class RootListWidget(QListWidget):
     def __init__(self, widget, owner):
         QListWidget.__init__(self, widget)
         self.setDragDropMode(self.InternalMove)
-        self.setMaximumSize(QSize(16777215, 120))
+        self.setMaximumSize(QSize(16777215, 120 * owner.dpiScale()))
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
         self.setSelectionMode(QAbstractItemView.SingleSelection)
         self.setDragEnabled(True)
@@ -103,10 +110,11 @@ class RootListWidget(QListWidget):
 
 # noinspection PyCallByClass,PyArgumentList
 class MainWindow(QMainWindow):
-    def __init__(self, app, ini=None, base_dir=None):
+    def __init__(self, app, ini=None, base_dir=None, plot_scale=1):
         """
         Initialize of GUI components.
         """
+
         super().__init__()
 
         self.setWindowTitle("GetDist GUI")
@@ -119,6 +127,7 @@ class MainWindow(QMainWindow):
         self.updating = False
         self.app = app
         self.base_dir = base_dir
+        self.plot_scale_fudge = plot_scale
 
         self.orig_rc = matplotlib.rcParams.copy()
         self.plot_module = 'getdist.plots'
@@ -154,7 +163,7 @@ class MainWindow(QMainWindow):
 
         # Path of root directory
         self.rootdirname = None
-        self.plotter = None
+        self.plotter: Optional[plots.GetDistPlotter] = None
         self.root_infos = {}
 
         self._resetGridData()
@@ -162,7 +171,8 @@ class MainWindow(QMainWindow):
 
         self.log_handler = QStatusLogger(self)
         logging.getLogger().addHandler(self.log_handler)
-        self._last_color = None
+
+        self._last_msg = ("", False)
 
         dirs = self.getSettings().value('directoryList')
         last_dir = self.getSettings().value('lastSearchDirectory')
@@ -176,7 +186,7 @@ class MainWindow(QMainWindow):
             if last_dir is not None and last_dir not in dirs and os.path.exists(last_dir):
                 dirs.insert(0, last_dir)
             self.listDirectories.addItems(dirs)
-            if last_dir is not None and os.path.exists(last_dir):
+            if last_dir and os.path.exists(last_dir):
                 self.listDirectories.setCurrentIndex(dirs.index(last_dir))
                 self.openDirectory(last_dir)
             else:
@@ -310,6 +320,9 @@ class MainWindow(QMainWindow):
         self.helpMenu.addSeparator()
         self.helpMenu.addAction(self.aboutAct)
 
+    def dpiScale(self):
+        return self.logicalDpiX() / 96
+
     def createStatusBar(self):
         """
         Create Qt status bar.
@@ -317,13 +330,14 @@ class MainWindow(QMainWindow):
         self.statusBar().setStyleSheet("height:1em")
         self.statusBar().showMessage("Ready", 2000)
 
-    def showMessage(self, msg='', color=None):
-        if not msg and not color and self._last_color:
+    def showMessage(self, msg='', error=False):
+        if (msg, error) == self._last_msg or not msg and self._last_msg[1]:
             return
-        self._last_color = color
+        self._last_msg = (msg, error)
         bar = self.statusBar()
         bar.showMessage(msg)
-        bar.setStyleSheet("color: %s" % (color or "black"))
+        bar.setStyleSheet("color: %s; " % ('red' if error else QApplication.palette().text().color().name()) +
+                          ("background-color: lightGray" if error else ""))
         if msg:
             self.statusBar().repaint()
             QCoreApplication.processEvents()
@@ -343,10 +357,13 @@ class MainWindow(QMainWindow):
         """
         Create widgets.
         """
-        if sys.platform in ["darwin", "Windows"]:
-            self.setStyleSheet("* {font-size:9pt} QComboBox,QPushButton {height:1.3em}")
+        scale = self.dpiScale()
+        if sys.platform in ["darwin", "win32"]:
+            self.setStyleSheet(
+                "* {font-size:%spt} QComboBox,QPushButton {height:%sem}" % (9, 1.3))
         else:
-            self.setStyleSheet("* {font-size:12px} QComboBox,QPushButton {height:1.3em}")
+            self.setStyleSheet(
+                "* {font-size:%spx} QComboBox,QPushButton {height:%sem}" % (12 * scale, 1.3))
 
         self.tabWidget = QTabWidget(self)
         self.tabWidget.setTabPosition(QTabWidget.East)
@@ -364,7 +381,7 @@ class MainWindow(QMainWindow):
         self.connect(self.listDirectories, SIGNAL("activated(const QString&)"), self.openDirectory)
 
         self.pushButtonSelect = QPushButton(self._icon("open"), "", self.selectWidget)
-        self.pushButtonSelect.setMaximumWidth(30)
+        self.pushButtonSelect.setFixedWidth(45 * self.dpiScale())
         self.pushButtonSelect.setToolTip("Open chain file root directory")
         self.connect(self.pushButtonSelect, SIGNAL("clicked()"), self.selectRootDirName)
 
@@ -375,7 +392,7 @@ class MainWindow(QMainWindow):
         self.pushButtonRemove = QPushButton(self._icon('remove'), "", self.selectWidget)
         self.pushButtonRemove.setToolTip("Remove a chain root")
         self.pushButtonRemove.setEnabled(False)
-        self.pushButtonRemove.setMaximumWidth(30)
+        self.pushButtonRemove.setMaximumWidth(30 * self.dpiScale())
         self.connect(self.pushButtonRemove, SIGNAL("clicked()"), self.removeRoot)
 
         self.comboBoxParamTag = QComboBox(self.selectWidget)
@@ -499,7 +516,8 @@ class MainWindow(QMainWindow):
         self.plotter_script = None
 
         self.toolBar = QToolBar()
-        self.toolBar.setIconSize(QSize(22, 22))
+        self.toolBar.setStyleSheet("background-color: lightGray; border: none")
+        self.toolBar.setIconSize(QSize(22 * self.dpiScale(), 22 * self.dpiScale()))
 
         openAct = QAction(self._icon("open"),
                           "open script", self.toolBar,
@@ -518,6 +536,7 @@ class MainWindow(QMainWindow):
         self.toolBar.addAction(clearAct)
 
         self.textWidget = QPlainTextEdit(self.editWidget)
+        self.textWidget.setStyleSheet("background-color: #FAF9F6; color: black; font-size: 10pt")
         textfont = QFont("Monospace")
         textfont.setStyleHint(QFont.TypeWriter)
         self.textWidget.setWordWrapMode(QTextOption.NoWrap)
@@ -567,13 +586,22 @@ class MainWindow(QMainWindow):
     def getSettings(self):
         return QSettings('getdist', 'gui')
 
+    def getScreen(self):
+        return QApplication.screenAt(self.mapToGlobal(QPoint(self.width() / 2, 0))).availableGeometry()
+
     def readSettings(self):
         settings = self.getSettings()
-        screen = QApplication.desktop().screenGeometry()
-        h = min(screen.height() * 4 / 5., 700)
-        size = QSize(min(screen.width() * 4 / 5., 900), h)
+        screen = self.getScreen()
+        h = min(screen.height() * 4 / 5., 700 * self.dpiScale())
+        size = QSize(min(screen.width() * 4 / 5., 900 * self.dpiScale()), h)
         pos = settings.value("pos", None)
-        savesize = settings.value("size", size)
+        savesize = settings.value("size", None)
+        if savesize is None:
+            savesize = size
+        else:
+            savesize *= self.dpiScale()
+        if pos is not None:
+            pos *= self.dpiScale()
         if savesize.width() > screen.width():
             savesize.setWidth(size.width())
         if savesize.height() > screen.height():
@@ -591,14 +619,37 @@ class MainWindow(QMainWindow):
 
     def writeSettings(self):
         settings = self.getSettings()
-        settings.setValue("pos", self.pos())
-        settings.setValue("size", self.size())
+        settings.setValue("pos", self.pos() / self.dpiScale())
+        settings.setValue("size", self.size() / self.dpiScale())
         settings.setValue('plot_module', self.plot_module)
         settings.setValue('script_plot_module', self.script_plot_module)
         splitter_settings = self.splitter.saveState()
         if splitter_settings:
             settings.setValue("splitter_settings", splitter_settings)
 
+    def create_message_box(self, title, text):
+        msg = QDialog(self, Qt.WindowSystemMenuHint | Qt.WindowTitleHint | Qt.WindowCloseButtonHint)
+        msg.setWindowTitle(title)
+
+        buttonBox = QDialogButtonBox(QDialogButtonBox.Ok)
+        buttonBox.accepted.connect(msg.accept)  # noqa
+        layout = QVBoxLayout()
+        message = QLabel(text)
+        message.setWordWrap(False)
+        message.setTextInteractionFlags(QtCore.Qt.TextSelectableByMouse)
+        layout.addWidget(message)
+        layout.addWidget(buttonBox)
+        msg.setLayout(layout)
+        msg.setAttribute(Qt.WA_DeleteOnClose)
+        msg.exec_()
+
+    def warning(self, title, message):
+        QApplication.restoreOverrideCursor()
+        if len(message) < 40:
+            QMessageBox.warning(self, title, message)
+        else:
+            self.create_message_box(title, message)
+
     def export(self):
         """
         Callback for action 'Export as PDF/Image'.
@@ -617,7 +668,7 @@ class MainWindow(QMainWindow):
             filename = str(filename)
             plotter.export(filename)
         else:
-            QMessageBox.warning(self, "Export", "No plotter data to export")
+            self.warning("Export", "No plotter data to export")
 
     def saveScript(self):
         """
@@ -631,7 +682,7 @@ class MainWindow(QMainWindow):
             script = self.script_edit
 
         if script == '':
-            QMessageBox.warning(self, "Script", "No script to save")
+            self.warning("Script", "No script to save")
             return
 
         filename, _ = QFileDialog.getSaveFileName(self, "Choose a file name", '.', "Python (*.py)")
@@ -644,7 +695,7 @@ class MainWindow(QMainWindow):
 
     def reLoad(self):
         adir = self.getSettings().value('lastSearchDirectory')
-        if adir is not None:
+        if adir:
             if batchjob:
                 batchjob.resetGrid(adir)
             self.openDirectory(adir)
@@ -659,7 +710,7 @@ class MainWindow(QMainWindow):
         if item is not None:
             rootname = str(item.text())
         if rootname is None:
-            QMessageBox.warning(self, "Chain Stats", "Select a root name first. ")
+            self.warning("Chain Stats", "Select a root name first. ")
         return rootname
 
     def showConvergeStats(self):
@@ -771,7 +822,7 @@ class MainWindow(QMainWindow):
         samples = self.getSamples(rootname)
         stats = samples.getLikeStats()
         if stats is None:
-            QMessageBox.warning(self, "Like stats", "Samples do not likelihoods")
+            self.warning("Like stats", "Samples do not likelihoods")
             return
         dlg = DialogLikeStats(self, stats, rootname)
         dlg.show()
@@ -788,7 +839,7 @@ class MainWindow(QMainWindow):
         Callback for action 'Show settings'
         """
         if not self.plotter:
-            QMessageBox.warning(self, "Settings", "Open chains first ")
+            self.warning("Settings", "Open chains first ")
             return
         self.settingDlg = self.settingDlg or DialogSettings(self, self.current_settings)
         self.settingDlg.show()
@@ -971,25 +1022,25 @@ class MainWindow(QMainWindow):
 
     def openPlanck(self):
         import webbrowser
-        webbrowser.open("http://pla.esac.esa.int/pla/#cosmology")
+        webbrowser.open("https://pla.esac.esa.int/pla/#cosmology")
 
     def about(self):
         """
         Callback for action 'About'.
         """
-        QMessageBox.about(self, "About GetDist GUI",
-                          "GetDist GUI v " + getdist.__version__ +
-                          "\nAntony Lewis (University of Sussex) and contributors" +
-                          "\nhttps://github.com/cmbant/getdist/\n" +
-                          "\nPython: " + sys.version +
-                          "\nMatplotlib: " + matplotlib.__version__ +
-                          "\nSciPy: " + scipy.__version__ +
-                          "\nNumpy: " + np.__version__ +
-                          "\nPySide2: " + PySide2.__version__ +
-                          "\nQt (PySide): " + PySide2.QtCore.__version__ +
-                          "\n\nPix ratio: %s; Logical dpi: %s, %s" % (
-                              self.devicePixelRatio(), self.logicalDpiX(), self.logicalDpiY()) +
-                          '\nUsing getdist at: %s' % os.path.dirname(getdist.__file__))
+        self.create_message_box("About GetDist GUI",
+                                "GetDist GUI v " + getdist.__version__ +
+                                "\nAntony Lewis (University of Sussex) and contributors" +
+                                "\nhttps://github.com/cmbant/getdist/\n" +
+                                "\nPython: " + sys.version +
+                                "\nMatplotlib: " + matplotlib.__version__ +
+                                "\nSciPy: " + scipy.__version__ +
+                                "\nNumpy: " + np.__version__ +
+                                "\nPySide2: " + PySide2.__version__ +
+                                "\nQt (PySide): " + PySide2.QtCore.__version__ +
+                                "\n\nPix ratio: %s; Logical dpi: %s, %s" % (
+                                    self.devicePixelRatio(), self.logicalDpiX(), self.logicalDpiY()) +
+                                '\nUsing getdist at: %s' % os.path.dirname(getdist.__file__))
 
     def getDirectories(self):
         return [self.listDirectories.itemText(i) for i in range(self.listDirectories.count())]
@@ -1017,10 +1068,10 @@ class MainWindow(QMainWindow):
         title = self.tr("Choose an existing chains grid or chains folder")
         dir_name = QFileDialog.getExistingDirectory(self, title, last_dir,
                                                     QFileDialog.ShowDirsOnly | QFileDialog.DontResolveSymlinks)
-        dir_name = os.path.abspath(str(dir_name))
-        logging.debug("dirName: %s" % dir_name)
         if dir_name is None or dir_name == '':
             return  # No directory selected
+        dir_name = os.path.abspath(str(dir_name))
+        logging.debug("dirName: %s" % dir_name)
 
         if self.openDirectory(dir_name, save=False):
             items = self.getDirectories()
@@ -1050,7 +1101,7 @@ class MainWindow(QMainWindow):
                         self.saveDirectories()
                     return True
 
-                QMessageBox.critical(self, "Open chains", "No chains or grid found in that directory")
+                self.warning("Open chains", "No chains or grid found in that directory")
                 cur_dirs = self.getDirectories()
                 if dirName in cur_dirs:
                     self.listDirectories.removeItem(cur_dirs.index(dirName))
@@ -1232,6 +1283,7 @@ class MainWindow(QMainWindow):
 
         self.updating = True
         item = QListWidgetItem(self.listRoots)
+        self._def_color = item.foreground()
         item.setText('Loading... ' + root)
         self.listRoots.addItem(item)
         self.listRoots.repaint()
@@ -1423,19 +1475,19 @@ class MainWindow(QMainWindow):
 
     def errorReport(self, e, caption="Error", msg="", capture=False):
         if isinstance(e, SettingError):
-            QMessageBox.critical(self, 'Setting error', str(e))
+            self.warning('Setting error', str(e))
         elif isinstance(e, ParamError):
-            QMessageBox.critical(self, 'Param error', str(e))
+            self.warning('Param error', str(e))
         elif isinstance(e, IOError):
-            QMessageBox.critical(self, 'File error', str(e))
+            self.warning('File error', str(e))
         elif isinstance(e, (GuiSelectionError, plots.GetDistPlotError)):
-            QMessageBox.critical(self, caption, str(e))
+            self.warning(caption, str(e))
         else:
             if not msg:
                 import traceback
 
                 msg = "\n".join(traceback.format_tb(sys.exc_info()[2])[-5:])
-            QMessageBox.critical(self, caption, type(e).__name__ + ': ' + str(e) + "\n\n" + msg)
+            self.warning(caption, type(e).__name__ + ': ' + str(e) + "\n\n" + msg)
             del msg
 
             if not isinstance(e, GuiSelectionError) and not capture:
@@ -1463,11 +1515,11 @@ class MainWindow(QMainWindow):
             roots = self.checkedRootNames()
             if not len(roots):
                 logging.warning("No rootname selected")
-                QMessageBox.warning(self, "Plot data", "No root selected")
+                self.warning("Plot data", "No root selected")
                 return
 
             if self.plotter is None:
-                QMessageBox.warning(self, "Plot data", "No GetDistPlotter instance")
+                self.warning("Plot data", "No GetDistPlotter instance")
                 return
             self.closePlots()
 
@@ -1530,9 +1582,16 @@ class MainWindow(QMainWindow):
 
             logging.debug("Plotting with roots = %s" % str(roots))
 
-            # fudge factor of 0.8 seems to help with overlapping labels on retina Mac.
-            height = self.plotWidget.height() / self.logicalDpiX() * 0.8
-            width = self.plotWidget.width() / self.logicalDpiX() * 0.8
+            # if devicePixelRatio>1, seem to have to render at the dpi-scaled small size, as then scaled up
+            # or, for some reason scaling the figure dpi this way works...
+            height = self.plotWidget.height() / self.logicalDpiX() * self.plot_scale_fudge  # / self.devicePixelRatio()
+            width = self.plotWidget.width() / self.logicalDpiX() * self.plot_scale_fudge  # / self.devicePixelRatio()
+            matplotlib.rcParams['figure.dpi'] = self.logicalDpiX() / self.devicePixelRatio()
+            if self.devicePixelRatio() > 1:
+                self.plotter.settings.direct_scaling = True
+            if sys.platform == 'darwin' and self.devicePixelRatio() == 1:
+                # no idea why this works for low-res attached to mac laptops
+                matplotlib.rcParams['figure.dpi'] /= 2
 
             def setSizeForN(cols, rows):
                 if self.plotter.settings.fig_width_inch is not None:
@@ -1677,13 +1736,14 @@ class MainWindow(QMainWindow):
                 text += "\n"
                 text += "3D plot: Select x parameter, y parameter and 'Color by' parameter\n"
                 text += "\n"
-                QMessageBox.warning(self, "Plot usage", text)
+                self.warning("Plot usage", text)
                 return
 
             script += "g.export()\n"
             self.script = script
             self.exportAct.setEnabled(True)
         except Exception as e:
+            QApplication.restoreOverrideCursor()
             self.errorReport(e, caption=actionText)
         finally:
             self.showMessage()
@@ -1698,6 +1758,9 @@ class MainWindow(QMainWindow):
                 item = self.plotWidget.layout().takeAt(i)
                 if item is None:
                     break
+                if hasattr(item, "widget"):
+                    child = item.widget()  # noqa
+                    del child
                 del item
             if hasattr(self, "canvas"):
                 del self.canvas
@@ -1705,6 +1768,7 @@ class MainWindow(QMainWindow):
                 del self.toolbar
             self.canvas = FigureCanvas(self.plotter.fig)
             self.toolbar = NavigationToolbar(self.canvas, self)
+            self.toolbar.setStyleSheet("QToolBar {background-color: lightGray; border: none}")
             self.plotWidget.layout().addWidget(self.toolbar)
             self.plotWidget.layout().addWidget(self.canvas)
             self.plotWidget.show()
@@ -1791,7 +1855,7 @@ class MainWindow(QMainWindow):
             self.exportAct.setEnabled(True)
 
         except SyntaxError as e:
-            QMessageBox.critical(self, "Plot script", type(e).__name__ + ': %s\n %s' % (e, e.text))
+            self.warning("Plot script", type(e).__name__ + ': %s\n %s' % (e, e.text))
         except Exception as e:
             self.errorReport(e, caption="Plot script", capture=True)
         finally:
@@ -1812,9 +1876,6 @@ class MainWindow(QMainWindow):
             item = self.plotWidget2.layout().takeAt(i)
             if item is None:
                 break
-            if hasattr(item, "widget"):
-                child = item.widget()
-                del child
             del item
 
         # Save in PNG format, and display it in a QLabel
@@ -1850,6 +1911,7 @@ class MainWindow(QMainWindow):
 # ==============================================================================
 
 
+# noinspection PyArgumentList
 class DialogTextOutput(QDialog):
     def __init__(self, parent, text=None):
         QDialog.__init__(self, parent, Qt.WindowSystemMenuHint | Qt.WindowTitleHint | Qt.WindowCloseButtonHint)
@@ -1883,7 +1945,7 @@ class DialogLikeStats(DialogTextOutput):
         self.setLayout(layout)
         self.setWindowTitle(self.tr('Sample likelihood constraints: ' + root))
 
-        self.text.setMaximumHeight(80)
+        self.text.setMaximumHeight(70 * parent.dpiScale())
         layout.addWidget(self.text, 0, 0)
 
         if stats:
@@ -1911,9 +1973,9 @@ class DialogLikeStats(DialogTextOutput):
             self.table.resizeRowsToContents()
             self.table.resizeColumnsToContents()
 
-            w = self.table.horizontalHeader().length() + 40
-            h = self.table.verticalHeader().length() + 40
-            h = min(QApplication.desktop().screenGeometry().height() * 4 / 5, h)
+            w = self.table.horizontalHeader().length() + 40 * parent.dpiScale()
+            h = self.table.verticalHeader().length() + 40 * parent.dpiScale()
+            h = min(parent.getScreen().height() * 4 / 5, h)
             self.resize(w, h)
 
 
@@ -1921,7 +1983,7 @@ class DialogLikeStats(DialogTextOutput):
 
 # noinspection PyArgumentList
 class DialogMargeStats(QDialog):
-    def __init__(self, parent=None, stats=None, root=''):
+    def __init__(self, parent, stats=None, root=''):
         QDialog.__init__(self, parent, Qt.WindowSystemMenuHint | Qt.WindowTitleHint | Qt.WindowCloseButtonHint)
 
         self.label = QLabel(self)
@@ -1962,9 +2024,9 @@ class DialogMargeStats(QDialog):
             self.table.resizeRowsToContents()
             self.table.resizeColumnsToContents()
 
-            w = self.table.horizontalHeader().length() + 40
-            h = self.table.verticalHeader().length() + 40
-            h = min(QApplication.desktop().screenGeometry().height() * 4 / 5, h)
+            w = self.table.horizontalHeader().length() + 40 * parent.dpiScale()
+            h = self.table.verticalHeader().length() + 40 * parent.dpiScale()
+            h = min(parent.getScreen().height() * 4 / 5, h)
             self.resize(w, h)
 
 
@@ -1977,14 +2039,13 @@ class DialogConvergeStats(DialogTextOutput):
         layout.addWidget(self.text, 1, 0)
         if summary:
             self.text2 = self.getTextBox(summary)
-            self.text2.setMaximumHeight(100)
+            self.text2.setMaximumHeight(80 * parent.dpiScale())
             layout.addWidget(self.text2, 0, 0)
 
         self.setLayout(layout)
         self.setWindowTitle(self.tr('Convergence stats: ' + root))
-        # noinspection PyArgumentList
-        h = min(QApplication.desktop().screenGeometry().height() * 4 / 5, 1200)
-        self.resize(700, h)
+        h = min(parent.getScreen().height() * 4 / 5, 1200 * parent.dpiScale())  # noqa
+        self.resize(700 * parent.dpiScale(), h)  # noqa
 
 
 # ==============================================================================
@@ -1997,8 +2058,8 @@ class DialogPCA(DialogTextOutput):
         self.setLayout(layout)
         self.setWindowTitle(self.tr('PCA constraints for: ' + root))
         # noinspection PyArgumentList
-        h = min(QApplication.desktop().screenGeometry().height() * 4 / 5, 800)
-        self.resize(500, h)
+        h = min(parent.getScreen().height() * 4 / 5, 800 * parent.dpiScale())
+        self.resize(500 * parent.dpiScale(), h)  # noqa
 
 
 # ==============================================================================
@@ -2030,8 +2091,6 @@ class DialogParamTables(DialogTextOutput):
         self.tabChanged(0)
 
         self.setWindowTitle(self.tr('Parameter tables for: ' + root))
-        # h = min(QApplication.desktop().screenGeometry().height() * 4 / 5, 800)
-        # self.resize(500, h)
         self.adjustSize()
 
     def tabChanged(self, index):
@@ -2134,7 +2193,8 @@ class DialogSettings(QDialog):
 
         self.table.resizeColumnsToContents()
         maxh = min(parent.rect().height(),
-                   (QApplication.desktop().screenGeometry().height() - parent.rect().top()) * 4 / 5)
+                   (parent.getScreen().height() - parent.rect().top()) * 4 / 5)
+        width *= parent.dpiScale()
         self.resize(width, maxh)
         self.table.setColumnWidth(1, self.table.width() - self.table.columnWidth(0))
         self.table.resizeRowsToContents()
@@ -2146,7 +2206,7 @@ class DialogSettings(QDialog):
         if pos.x() - width > 0:
             pos.setX(pos.x() - width - 1)
             self.move(pos)
-        elif parent.frameGeometry().right() + width < QApplication.desktop().screenGeometry().width():
+        elif parent.frameGeometry().right() + width < parent.getScreen().width():
             pos.setX(parent.frameGeometry().right() + 1)
             self.move(pos)
 
@@ -2183,6 +2243,8 @@ def run_gui():
     parser = argparse.ArgumentParser(description='GetDist GUI')
     parser.add_argument('-v', '--verbose', help='verbose', action="store_true")
     parser.add_argument('--ini', help='Path to .ini file', default=None)
+    parser.add_argument('--plot_scale', help='fudge scaling for preview window', type=float, default=1)
+
     parser.add_argument('-V', '--version', action='version', version='%(prog)s ' + getdist.__version__)
     args = parser.parse_args()
 
@@ -2195,9 +2257,16 @@ def run_gui():
     logging.captureWarnings(True)
 
     sys.argv[0] = 'GetDist GUI'
-    app = QApplication(sys.argv)
+    app = QApplication(sys.argv)  # noqa
     app.setApplicationName("GetDist GUI")
-    mainWin = MainWindow(app, ini=args.ini)
+    mainWin = MainWindow(app, ini=args.ini, plot_scale=args.plot_scale)
+
+    def load_info(message):
+        print(message)
+        mainWin.showMessage(message)
+
+    chains.print_load_line = load_info
+
     mainWin.show()
     mainWin.raise_()
     sys.exit(app.exec_())
